.TH \ register_backup_proc n 2.3 Burt "Burt Commands"
.SH NAME
register_backup_proc \- register user level Tcl procedure for backups.
.SH SYNOPSIS
.B register_backup_proc
.I backuptype
.I procname
.SH DESCRIPTION
This command allows a user to register a procedure,
.I procname,
to be called when a
.I backuptype
backup type is encountered by Burt.  When a registered procedure is called
by Burt, it will be passed 3 arguments:  
.I host, 
.I atom, 
and 
.I level.  
.I host 
is the hostname of the machine to be backed up, 
.I atom 
is the filesystem/vol, and 
.I level
is the level of this backup.  These arguments are supplied by a user when
building a schedule list, so it is up the user to interpret the 
meaning of these arguments.  For example, for a UNIX-like backup, 
.I level
may be a number, whereas for an AFS backup,
.I level 
may be a date.
.PP
These procedures must return a Tcl list of two elements.  Failing to
do so will cause a Burt runtime error which will be noted in the logchannel.
The first element of the list must be an open readable channel representing the
data stream for the backup; data from this channel is written to tape.  The 
second element must be an open readable channel representing the stderr for 
the backup; data from this channel is passed a second user-defined Tcl procedure
which is registered via 
.B register_backupmonitor_proc(n),
and then written to the logchannel.  See 
.B register_backupmonitor_proc(n)
for more information.

.SH EXAMPLE Backup Procedure
As an example, here is the backup procedure used to backup dumps of the type
"ufs" at the University of Wisconsin, Madison, and the call to 
register_backup_proc used to register that procedure and thereby make it visible
to Burt:

proc ufs_dump {host atom level} {
    set hostlogfile /tmp/$host[info cmdcount]
    set dumpfd [open "|/s/std/bin/rsh $host -n \\"/etc/dump ${level}uf - $atom\\" 2> $hostlogfile" {RDONLY NONBLOCK}]

    set stderrfd [open $hostlogfile r]
    return [list $dumpfd $stderrfd]

}

register_backup_proc ufs ufs_dump

.SH SEE ALSO
register_backupmonitor_proc(n), register_recover_proc(n)

