.TH \ register_recover_proc n 2.3 Burt "Burt Built-In Commands"
.SH NAME
register_recover_proc \- register user level Tcl procedure for recovers.
.SH SYNOPSIS
.C register_recover_proc
.I backuptype
.I procname
.SH DESCRIPTION
This command allows a user to register a procedure,
.I procname,
to be called when a
.I backuptype
recover is encountered.  When a registered procedure is called by Burt,
it will be passed 3 arguments:  
.I host, 
.I atom, 
and 
.I level.  
.I host 
is the hostname of the machine being recovered, 
.I atom 
is the filesystem or volume being recovered, and 
.I level
is the level of the backup being recovered.  
It is up the user to interpret the meaning of these arguments; they 
represent the information specified by the user at the time of the backup.
.PP
These registered Tcl procs must return a single element.  Failing to to so
will cause a Burt runtime error, which will be noted in the logchannel.
This element must be an open writable channel; data from the tape that is
from the same host, atom, level and type will be written to this channel.

.SH EXAMPLE Recover Procedure
As an example, here is the recover procedure used to recover backups of the
type "ufs" from Burt tapes, and the call to register_backup_proc used to
make the procedure visible to Burt:

proc ufs_recover {host atom level} {
    set filename "$host"
    if { [string compare $atom "/"] == 0 } {
        append filename ".root"
    } else {
        regsub -all {/} $atom "." newatom
        append filename "$newatom"
    }
    append filename ".$level.burt"
    return [open "|cat > $filename" w]
}   

register_recover_proc ufs ufs_recover

.SH SEE ALSO
register_backupmonitor_proc(n), register_backup_proc(n)

